[cfe-commits] r70865 - in /cfe/trunk: include/clang/Analysis/PathSensitive/ValueManager.h lib/Analysis/SVals.cpp lib/Analysis/Store.cpp

Ted Kremenek kremenek at apple.com
Mon May 4 08:17:38 PDT 2009


Author: kremenek
Date: Mon May  4 10:17:38 2009
New Revision: 70865

URL: http://llvm.org/viewvc/llvm-project?rev=70865&view=rev
Log:
Rename 'makeZeroIndex' to 'makeZeroArrayIndex'.

Modified:
    cfe/trunk/include/clang/Analysis/PathSensitive/ValueManager.h
    cfe/trunk/lib/Analysis/SVals.cpp
    cfe/trunk/lib/Analysis/Store.cpp

Modified: cfe/trunk/include/clang/Analysis/PathSensitive/ValueManager.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/Analysis/PathSensitive/ValueManager.h?rev=70865&r1=70864&r2=70865&view=diff

==============================================================================
--- cfe/trunk/lib/Analysis/SVals.cpp (original)
+++ cfe/trunk/lib/Analysis/SVals.cpp Mon May  4 10:17:38 2009
@@ -227,7 +227,7 @@
   return UnknownVal();  
 }
 
-SVal ValueManager::makeZeroIndex() {
+SVal ValueManager::makeZeroArrayIndex() {
   return nonloc::ConcreteInt(BasicVals.getZeroWithPtrWidth(false));
 }
 

Modified: cfe/trunk/lib/Analysis/Store.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Analysis/Store.cpp?rev=70865&r1=70864&r2=70865&view=diff

==============================================================================
--- cfe/trunk/lib/Analysis/Store.cpp (original)
+++ cfe/trunk/lib/Analysis/Store.cpp Mon May  4 10:17:38 2009
@@ -65,7 +65,7 @@
       if (const TypedRegion *TR = dyn_cast<TypedRegion>(R)) {
         // Check if we are casting to a region with an integer type.  We now
         // the types aren't the same, so we construct an ElementRegion.
-        SVal Idx = ValMgr.makeZeroIndex();
+        SVal Idx = ValMgr.makeZeroArrayIndex();
         
         // If the super region is an element region, strip it away.
         // FIXME: Is this the right thing to do in all cases?





More information about the cfe-commits mailing list
--- cfe/trunk/include/clang/Analysis/PathSensitive/ValueManager.h (original)
+++ cfe/trunk/include/clang/Analysis/PathSensitive/ValueManager.h Mon May  4 10:17:38 2009
@@ -76,9 +76,9 @@
   
   /// makeZeroVal - Construct an SVal representing '0' for the specified type.
   SVal makeZeroVal(QualType T);
   /// makeZeroIndex - Construct an SVal representing '0' index for array
   /// elements.
-  SVal makeZeroIndex();
+  SVal makeZeroArrayIndex();
 
   /// GetRValueSymbolVal - make a unique symbol for value of R.
   SVal getRValueSymbolVal(const MemRegion* R);
@@ -76,9 +76,9 @@
   /// makeZeroVal - Construct an SVal representing '0' for the specified type.
   SVal makeZeroVal(QualType T);
-  /// makeZeroIndex - Construct an SVal representing '0' index for array
+  /// makeZeroArrayIndex - Construct an SVal representing '0' index for array
   /// elements.

Modified: cfe/trunk/lib/Analysis/SVals.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Analysis/SVals.cpp?rev=70865&r1=70864&r2=70865&view=diff

==============================================================================